@@ -3,7 +3,7 @@
 # ansible for now
 
 import argparse
-from datetime import datetime
+from datetime import datetime, timezone
 from os import path
 import sys
 import random
@@ -140,7 +140,7 @@ class ScreenPublisher(Publisher):
         data = {
             'name': "screen_pub",
             'text': text,
-            'timestamp':  datetime.now().isoformat(),
+            'timestamp':   datetime.now(timezone.utc).isoformat(),
             'rotation': self.rotation,
             'min_update_interval': 15*60, # 15m
             'force_update': self.first_loop or self.no_loop
