@@ -11,10 +11,13 @@ from sudoisbot.sendmsg import send_msg, send_to_me
 
 
 def main():
-    parser = argparse.ArgumentParser("Send messages with as @sudoisbot")
+    parser = argparse.ArgumentParser(
+        description="Send messages with as @sudoisbot",
+        add_help=False)
     parser.add_argument(
         "message", help="Message to send, read stdin otherwise", nargs='?'
     )
+    parser.add_argument("-m", action="store_true", help="ignored, legacy")
     parser.add_argument(
         "-t",
         "--to",
@@ -26,7 +29,7 @@ def main():
         action='store_true',
         default=False
     )
-    config, args = init("telegram", argparser=parser)
+    config, args = init("telegram", parser)
 
     if not args.message and args.code:
         parser.error("--code not valid when using stdin")
@@ -37,6 +40,8 @@ def main():
             text = codeblock(args.message)
         else:
             text = args.message
+    elif args.m:
+        text = "-m"
     else:
         stdin = fileinput.input('-')
         text = codeblock("\n".join(stdin))
